package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ColumnDataFeign;
import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.AmsSaleOrderMaterial;
import com.steerinfo.dil.service.IAmsSaleOrderMaterialService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * AmsSaleOrderMaterial RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-09-06 07:10
 * 类描述
 * 修订历史：
 * 日期：2021-09-06
 * 作者：generator
 * 参考：
 * 描述：AmsSaleOrderMaterial RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amssaleordermaterials")
public class AmsSaleOrderMaterialController extends BaseRESTfulController {

    @Autowired
    IAmsSaleOrderMaterialService amsSaleOrderMaterialService;

    @Autowired
    ColumnDataFeign columnDataFeign;

    @Autowired
    ColumnDataUtil columnDataUtil;

    @Autowired
    ESFeign esFeign;

    /**
     * 新增销售订单物资信息
     * @param amsSaleOrderMaterial
     * @return
     */
    @ApiOperation(value="新增销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/addAmsSaleOrderMaterial")
    public RESTfulResult addAmsSaleOrderMaterial(@RequestBody(required = false) AmsSaleOrderMaterial amsSaleOrderMaterial){
        int i = amsSaleOrderMaterialService.addAmsSaleOrderMaterial(amsSaleOrderMaterial);
        return success(i);
    }

    /**
     * 通过主键渲染销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键渲染销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/getAmsSaleOrderMaterialBySaleOrderMaterialId")
    public RESTfulResult getAmsSaleOrderMaterialBySaleOrderMaterialId(@RequestParam BigDecimal saleOrderMaterialId){
        List<Map<String, Object>> maps = amsSaleOrderMaterialService.selectBySaleOrderMaterialId(saleOrderMaterialId);
        return success(maps);
    }

    /**
     * 通过主键修改销售订单物资信息
     * @param amsSaleOrderMaterial
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amsSaleOrderMaterial", value = "销售订单物资信息对象", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/updateAmsSaleOrderMaterial")
    public RESTfulResult updateAmsSaleOrderMaterial(@RequestBody(required = false) AmsSaleOrderMaterial amsSaleOrderMaterial){
        int i = amsSaleOrderMaterialService.updateAmsSaleOrderMaterial(amsSaleOrderMaterial);
        return success(i);
    }

    /**
     * 通过主键删除销售订单物资信息
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键删除销售订单物资信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    public RESTfulResult deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId){
        int i = amsSaleOrderMaterialService.deleteAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
        return success(i);
    }

    /**
     * 通过主键获取收货地址
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="通过主键获取收货地址")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "saleOrderMaterialId", value = "主键Id", required = false, dataType = "java.math.BigDecimal")
    })
    @PostMapping(value = "/getAddress")
    public RESTfulResult getAddress(@RequestParam BigDecimal saleOrderMaterialId){
        String address = amsSaleOrderMaterialService.getAddress(saleOrderMaterialId);
        return success(address);
    }

    /**
     * 通过主键修改销售订单信息(新增一条），过去的成为历史记录
     * @param map
     * @return
     */
    @ApiOperation(value="通过主键修改销售订单信息(新增一条），过去的成为历史记录")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "销售订单物资信息map", required = false, dataType = "java.util.Map")
    })
    @PostMapping(value = "/updateAddress")
    public RESTfulResult updateAddress(@RequestBody(required = false) Map<String,Object> map){
        int i = amsSaleOrderMaterialService.updateAddress(map);
        return success(i);
    }

    /**
     * 获取收货地址
     * @param
     * @return
     */
    @ApiOperation(value="获取收货地址")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getAddressDeliveryAddress")
    public RESTfulResult getAddressDeliveryAddress(){
        return success(amsSaleOrderMaterialService.getAddressDeliveryAddress());
    }


    /**
     * 展示车序号信息
     * @param mapValue
     * @return
     */
    @ApiOperation(value="展示车序号信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "map", value = "销售订单物资信息map", required = false, dataType = "java.util.Map"),
            @ApiImplicitParam(name = "apiId", value = "411", required = false, dataType = "java.util.Map")
    })
    @PostMapping(value = "/getTruckNoList")
    public RESTfulResult getTruckNoList(@RequestBody(required = false) Map<String,Object> mapValue,
                                        Integer apiId,
                                        Integer pageNum,
                                        Integer pageSize,
                                        Integer issueStatus){
        if (issueStatus != null) {
            mapValue.put("issueStatus",issueStatus);
        }
        //不分页筛选数据
        PageHelper.startPage(pageNum,pageSize);
        //分页数据
        List<Map<String, Object>> saleOrderList = amsSaleOrderMaterialService.getTruckNoList(mapValue);
        PageListAdd pageList = columnDataUtil.tableColumnData(apiId, null,saleOrderList);
        return success(pageList);
    }

    /**
     * 车序号与物资新增
     * @param mapList
     * @return
     */
    @ApiOperation(value="车序号与物资新增")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "addTruckNo", value = "车序号与物资新增", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/addTruckNo")
    public RESTfulResult addTruckNo(@RequestBody List<Map<String,Object>> mapList){
        System.out.println("mapList"+mapList);
        int result = amsSaleOrderMaterialService.addTruckNo(mapList);
        return success(result);
    }

    /**
     * 下发车序号
     * @param mapList
     * @return
     */
    @ApiOperation(value="下发车序号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "issueTruckNo", value = "车序号列表", required = false, dataType = "AmsSaleOrderMaterial")
    })
    @PostMapping(value = "/issueTruckNo")
    public RESTfulResult issueTruckNo(@RequestBody List<Map<String,Object>> mapList){
        int result = amsSaleOrderMaterialService.issueTruckNo(mapList);
        return success(result);
    }

    /**
     * 展示车序号下的物资详情
     * @param saleOrderMaterialId
     * @return
     */
    @ApiOperation(value="展示车序号下的物资详情")
    @PostMapping(value = "/getTruckNoMaterialList")
    public RESTfulResult getTruckNoMaterialList(@RequestParam Integer saleOrderMaterialId){
        List<Map<String, Object>> truckNoMaterialList = amsSaleOrderMaterialService.getTruckNoMaterialList(new BigDecimal(saleOrderMaterialId));
        return success(truckNoMaterialList);
    }

    /**
     * 展示销售订单下的物资详情
     * @param saleOrderId
     * @return
     */
    @ApiOperation(value="展示销售订单下的物资详情")
    @PostMapping(value = "/getSaleMaterialList")
    public RESTfulResult getSaleMaterialList(@RequestParam Integer saleOrderId){
        List<Map<String, Object>> saleMaterialList = amsSaleOrderMaterialService.getSaleMaterialList(new BigDecimal(saleOrderId));
        return success(saleMaterialList);
    }

    @ApiOperation(value="销售直接选择车牌号派发运输订单")
    @PostMapping("dispatchTruckOrderBySale")
    public RESTfulResult dispatchTruckOrderBySale(@RequestBody Map<String,Object> mapValue){
        int result = amsSaleOrderMaterialService.dispatchTruckOrderBySale(mapValue);
        if (result == -1) {
            return failed("该销售订单的净重已达到97%");
        }
        else {
            return success(result);
        }
    }

    @ApiOperation(value="内转钢材派发订单")
    @PostMapping("dispatchInwardTruckOrderBySale")
    public RESTfulResult dispatchInwardTruckOrderBySale(@RequestBody Map<String,Object> mapValue){
        int result = amsSaleOrderMaterialService.dispatchInwardTruckOrderBySale(mapValue);
        return success(result);

    }

    @ApiOperation(value = "更新内转钢材收货客户")
    @PostMapping("/updateInwardConsignee")
    public RESTfulResult updateInwardConsignee(@RequestBody(required = false)Map<String,Object>map){
        return success(amsSaleOrderMaterialService.updateInwardConsignee(map));
    }

    @ApiOperation(value="承运商直接选择车牌号派发运输订单")
    @PostMapping("dispatchTruckOrderByCarrier")
    public RESTfulResult dispatchTruckOrderByCarrier(@RequestBody Map<String,Object> mapValue){
        int result = amsSaleOrderMaterialService.dispatchTruckOrderByCarrier(mapValue);
        if (result==-1){
            return failed("您的账号还没有绑定组织,请联系自动化部");
        }
        return success(result);
    }

    @ApiOperation(value="关闭销售订单")
    @PostMapping("closeSaleOrder")
    public RESTfulResult closeSaleOrder(@RequestParam Integer saleOrderId){
        int result = amsSaleOrderMaterialService.closeSaleOrder(new BigDecimal(saleOrderId));
        return success(result);
    }

    @ApiOperation(value = "得到单价和单价id")
    @PostMapping("/getPriceMap")
    public RESTfulResult getPriceMap(@RequestBody Map<String,Object> map) {
        Map<String,Object> priceMap = amsSaleOrderMaterialService.getPriceMap(map);
        return success(priceMap);
    }

    @ApiOperation(value = "得到单价和单价id")
    @PostMapping("/getBenPrice")
    public RESTfulResult getBenPrice(@RequestBody Map<String,Object> map) {
        Map<String,Object> priceMap = amsSaleOrderMaterialService.getBenPrice(map);
        return success(priceMap);
    }

    @ApiOperation("批量保存内转钢材到异地库收货单位和发站")
    @PostMapping("batchUpdateInwardConsignee")
    public RESTfulResult batchUpdateInwardConsignee(@RequestBody List<Map<String,Object>> maplist){
        int i = 0;
        for(Map<String,Object> map : maplist){
            i += amsSaleOrderMaterialService.updateInwardConsignee(map);
        }
        return success(i);

    }
}
