package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.ESFeign;
import com.steerinfo.dil.model.AmstruckInwardRequirement;
import com.steerinfo.dil.service.IAmstruckInwardRequirementService;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.dil.util.ColumnDataUtil;
import com.steerinfo.dil.util.DataChange;
import com.steerinfo.dil.util.PageListAdd;
import com.steerinfo.framework.controller.RESTfulResult;
import com.steerinfo.framework.service.pagehelper.PageHelper;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.text.SimpleDateFormat;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * AmstruckInwardRequirement RESTful接口：
 * @author generator
 * @version 1.0-SNAPSHORT 2021-10-25 11:30
 * 类描述
 * 修订历史：
 * 日期：2021-10-25
 * 作者：generator
 * 参考：
 * 描述：AmstruckInwardRequirement RESTful接口
 * @see null
 * @Copyright 湖南视拓信息技术股份有限公司. All rights reserved.
 */
@RestController
@RequestMapping("/${api.version}/amstruckinwardrequirement")
public class AmstruckInwardRequirementController extends BaseRESTfulController {

    @Autowired
    IAmstruckInwardRequirementService amstruckInwardRequirementService;
    @Autowired
    ColumnDataUtil columnDataUtil;
    @Autowired
    ESFeign esFeign;

    private final SimpleDateFormat sdfDateTime = new SimpleDateFormat("yyyy-MM-dd HH:mm:ss");
    /**
     *用车单位提出需求
     *新增用车需求
     */
    @PostMapping("/addTruckRequirement")
    public RESTfulResult addTruckRequirement(@RequestBody Map<String,Object> mapValue) {
        int result = amstruckInwardRequirementService.insert(mapValue);
        return success(result);
    }

    /*
    新增采购内转需求
     */
    @PostMapping("/addPurInwardRequirement")
    public RESTfulResult addPurInwardRequirement(@RequestBody Map<String,Object>mapValue){
        int result = amstruckInwardRequirementService.insertPurInwardRequirement(mapValue);
        return success(result);
    }


    /**
     * 删除用车需求
     */
    @PostMapping("/deleteTruckRequirement/{requirementId}")
    public RESTfulResult deleteTruckRequirement(@PathVariable("requirementId") BigDecimal requirementId) {
        int result = amstruckInwardRequirementService.deleteTruckRequirement(requirementId);
        return success(result);
    }
    /**
     * 修改用车需求/下发用车需求
     */
    @PostMapping("/updateTruckRequirement")
    public RESTfulResult updateTruckRequirement(@RequestBody AmstruckInwardRequirement amstruckInwardRequirement) {
        int result = amstruckInwardRequirementService.updateTruckRequirement(amstruckInwardRequirement);
        return success(result);
    }

    /**
     * 查询修改渲染
     */
    @PostMapping("/selectRequirement/{requirementId}")
    public RESTfulResult selectRequirement(@PathVariable("requirementId") Integer requirementId) {
        List<Map<String,Object>> result = amstruckInwardRequirementService.selectRequirement(requirementId);
        return success(result);
    }



    /**
     * 下发需求
     */
    @PostMapping("/downRequirement")
    public RESTfulResult downRequirement(@RequestBody List<Map<String,Object>> requirementIds) {
        int result = amstruckInwardRequirementService.downRequirement(requirementIds);
        return success(result);
    }

    /**
     * 接收需求
     */
    @PostMapping("/receiveRequirement/{requirementId}")
    public RESTfulResult receiveRequirement(@PathVariable("requirementId") Integer requirementId) {
        int result = amstruckInwardRequirementService.receiveRequirement(requirementId);
        return success(result);
    }

    /*
    根据需求ID查询需求详情
     */
    @PostMapping("/getRequirementMaterial/{requirementId}")
    public RESTfulResult getRequirementMaterial(@PathVariable("requirementId") Integer requirementId) {
        List<Map<String,Object>> listMap = amstruckInwardRequirementService.getRequirementMaterial(requirementId);
        return success(listMap);
    }

    /**
     * 展示未下发的用车需求
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示用车需求")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "207(0,1)/250(2)", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "requirementStatus", value = "需求状态", required = false, dataType = "Integer")
    })
    @PostMapping("/getTruckRequirementList")
    public RESTfulResult getTruckRequirementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId,
                                                 Integer requirementStatus,
                                                 String orgCode,
                                                 String index,
                                                 String startTime,
                                                 String endTime) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        if (orgCode != null && !orgCode.equals("null")) {
            String con = "%"+orgCode+"%";
            mapValue.put("con",con);
        }
        if (index != null && !"null".equals(index)) {
            mapValue.put("index","%"+index+"%");
        }
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        mapValue.put("requirementStatus",requirementStatus);
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckInwardRequirementService.getTruckRequirementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }
    //展示采购内转需求
    @PostMapping("/getPurRequirementList")
    public RESTfulResult getPurRequirementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId,
                                                 Integer requirementStatus,
                                                 String con,
                                                 String userId,
                                                 String carrierSsoId,
                                                 String enableStatus,
                                                 String planStatus,
                                               String startTime,
                                               String endTime,
                                               BigDecimal planId) {

        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        if(userId != null){
            mapValue.put("userId",userId);
        }
        if(carrierSsoId != null){
            mapValue.put("carrierSsoId",carrierSsoId);
        }
        if(enableStatus != null){
            mapValue.put("enableStatus",enableStatus);
        }
        if(planStatus != null){
            mapValue.put("planStatus",DataChange.dataToBigDecimal(planStatus));
        }
        if(con != null && !"null".equals(con)){
            mapValue.put("con","%" + con + "%");
        }
        if(planId != null && !"null".equals(planId)){
            mapValue.put("planId", planId);
        }
        mapValue.put("requirementStatus",requirementStatus);
        DataChange.queryDataByDateTime(startTime, endTime, mapValue,sdfDateTime);//根据时间段查询数据
        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckInwardRequirementService.getPurRequirementList(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }



    @ApiModelProperty(value = "展示批次信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "252", required = false, dataType = "Integer"),
    })
    @PostMapping("/getPurchaseIdByBatch")
    public RESTfulResult getPurchaseIdByBatch(@RequestBody(required = false) Map<String,Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId,
                                                 String  con) {

        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckInwardRequirementService.getPurchaseIdByBatch(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }


    //异地库下拉框
    @GetMapping("/getOffsetWarehouse")
    public RESTfulResult getOffsetWarehouse(){
        List<Map<String,Object>> mapList =  amstruckInwardRequirementService.getOffsetWareHouse();
        return success(mapList);
    }


    @ApiModelProperty(value = "仓库模代框")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "251", required = false, dataType = "Integer"),
    })
    @PostMapping("/getWareHouse")
    public RESTfulResult getWareHouse(@RequestBody(required = false) Map<String,Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId,
                                              String con) {

        PageHelper.startPage(pageNum, pageSize);
        //分页查询数据
        List<Map<String, Object>> columnList = amstruckInwardRequirementService.getWareHouse(mapValue);
        PageListAdd data = columnDataUtil.tableColumnData(apiId, null, columnList);
        return success(data);
    }

    /**
     * 承运商下拉
     * @return
     */
    @GetMapping("/getCapacityType")
    public RESTfulResult getCapacityType() {
        List<Map<String,Object>> mapList = amstruckInwardRequirementService.getCapacityType();
        return success(mapList);
    }

    /**
     * 发货单位下拉
     * @return
     */
    @GetMapping("/getShipperUser")
    public RESTfulResult getShipperUser() {
        List<Map<String,Object>> mapList = amstruckInwardRequirementService.getShipperUser();
        return success(mapList);
    }



}
